# biospat


[![image](https://img.shields.io/pypi/v/biospat.svg)](https://pypi.python.org/pypi/biospat)
[![image](https://img.shields.io/conda/vn/conda-forge/biospat.svg)](https://anaconda.org/conda-forge/biospat)

[![image](https://pyup.io/repos/github/anytko/biospat/shield.svg)](https://pyup.io/repos/github/anytko/biospat)


**Biodiversity Spatial Analysis - A python package to characterize the ecosystem function, traits, and diversity of populations of a species across its range.**


-   Free software: MIT License
-   Documentation: https://anytko.github.io/biospat


## Features

-  Visualize species' ranges at multiple spatial scales
-  Characterize leading edges, trailing edges, and core distributions from a species' range
-  Identify the ecosystem function, traits, genetic diversity, and evolutionary potential of populations across a species' range
